@@ -39,10 +39,19 @@ if __name__ == "__main__":
     default_tags = []
     for extra_lib in ('pygments', 'wavedrom'):
         try:
-            importlib.import_module(extra_lib)
+            mod = importlib.import_module(extra_lib)
         except ImportError:
             log.warning("skipping %s tests ('%s' module not found)" % (extra_lib, extra_lib))
             default_tags.append("-%s" % extra_lib)
+        else:
+            if extra_lib == 'pygments':
+                version = tuple(int(i) for i in mod.__version__.split('.')[:3])
+                if version >= (2, 14, 0):
+                    tag = "pygments<2.14"
+                else:
+                    tag = "pygments>=2.14"
+                log.warning("skipping %s tests (pygments %s found)" % (tag, mod.__version__))
+                default_tags.append("-%s" % tag)
 
     retval = testlib.harness(testdir_from_ns=testdir_from_ns,
                              default_tags=default_tags)
